@@ -4,7 +4,6 @@ from conductor.client.configuration.settings.metrics_settings import MetricsSett
 from conductor.client.telemetry.metrics_collector import MetricsCollector
 from conductor.client.worker.worker import Worker
 from conductor.client.worker.worker_interface import WorkerInterface
-from conductor.client.worker.worker_task import WorkerTask
 from multiprocessing import Process, freeze_support
 from typing import List
 import ast
@@ -31,12 +30,14 @@ def get_annotated_workers():
 class TaskHandler:
     def __init__(
             self,
-            workers: List[WorkerInterface],
+            workers: List[WorkerInterface] = None,
             configuration: Configuration = None,
             metrics_settings: MetricsSettings = None,
             scan_for_annotated_workers: bool = None,
     ):
-        if not isinstance(workers, list):
+        if workers is None:
+            workers = []
+        elif not isinstance(workers, list):
             workers = [workers]
         if scan_for_annotated_workers is True:
             for worker in get_annotated_workers():
